==> hs-pango-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/pango-0.12.0/register.sh <==
#!/bin/sh
echo 'name: pango
version: 0.12.0
id: pango-0.12.0-f434ae0cbcfb06326a9578191b9d68f9

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: stable
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: This package provides a wrapper around the Pango C library that
             allows high-quality rendering of Unicode text. It can be used
             either with Cairo to output text in PDF, PS or other
             documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: Graphics.Rendering.Pango
                 Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Enums
                 Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Layout
                 Graphics.Rendering.Pango.Rendering Graphics.Rendering.Pango.Markup
                 Graphics.Rendering.Pango.Cairo Graphics.Rendering.Pango.Types
                 Graphics.Rendering.Pango.BasicTypes
                 Graphics.Rendering.Pango.Structs
                 Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/pango-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/pango-0.12.0
              /usr/local/lib
hs-libraries: HSpango-0.12.0
extra-libraries: pangocairo-1.0 cairo pangoft2-1.0 pango-1.0 m
                 freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/pango-1.0
              /usr/local/include/glib-2.0 /usr/local/include/cairo
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng
includes: hspango.h
depends: array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         cairo-0.12.0-0298aadd5c50de52030d550500daacb0
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         directory-1.1.0.0-ccdcf043bf8bcec9518fbfad880579a5
         glib-0.12.0-8ee4233c74a76a3c53a9d5252cb0d3ba
         haskell98-1.1.0.1-d297a29bdc63fd1be05662f1882b09e7
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
         pretty-1.0.1.2-abc7c632374e50e1c1927987c2651f0f
         process-1.0.1.5-4cab1bf0666275ac101dd48c7565b64c
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/pango-0.12.0/html/pango.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/pango-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-pango-0.12.2.tbz: lib/ghc-7.0.4/cabal/pango-0.12.2/register.sh <==
#!/bin/sh
echo 'name: pango
version: 0.12.2
id: pango-0.12.2-940a57a1d080812b6ad7997572bc4304

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: This package provides a wrapper around the Pango C library that
             allows high-quality rendering of Unicode text. It can be used
             either with Cairo to output text in PDF, PS or other
             documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: Graphics.Rendering.Pango
                 Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Enums
                 Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Layout
                 Graphics.Rendering.Pango.Rendering Graphics.Rendering.Pango.Markup
                 Graphics.Rendering.Pango.Cairo Graphics.Rendering.Pango.Types
                 Graphics.Rendering.Pango.BasicTypes
                 Graphics.Rendering.Pango.Structs
                 Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/pango-0.12.2
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/pango-0.12.2
              /usr/local/lib
hs-libraries: HSpango-0.12.2
extra-libraries: pangocairo-1.0 cairo pangoft2-1.0 pango-1.0 m
                 freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/pango-1.0
              /usr/local/include/glib-2.0 /usr/local/include/cairo
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng
includes: hspango.h
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         cairo-0.12.2-3c2fec1f88a91352e69551a3e4e32b3e
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         directory-1.1.0.0-689c0feb497f60ef9b6c9a128fc1997e
         glib-0.12.2-14d626c7282f5f31da9b4a299a29106c
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         pretty-1.0.1.2-6970e62db724fea03caad23f58dd8f86
         process-1.0.1.5-55dfaccf3a91c4cb8f6284a0bafef198
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/pango-0.12.2/html/pango.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/pango-0.12.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
